# kegbot-pyutils

This is a small collection of common Python library code used in the Kegbot
project.

Homepage: https://github.com/Kegbot/kegbot-pyutils

For documentation and more information, see https://kegbot.org/docs

## License and Copyright

All code is offered under the **MIT** license, unless otherwise noted.  Please
see `LICENSE.txt` for the full license.

